@@ -4,6 +4,8 @@
 #include <dmalloc.h>
 #endif
 
+#include <string.h>
+
 #include "suck_config.h"
 #include "suck.h"
 #include "suckutils.h"
@@ -22,15 +24,15 @@ void inssort(PList *, int, int);
 
 /* Support functions */
 
-#ifndef min 
-#define min(a, b) ((a)<=(b) ? (a) : (b)) 
+#ifndef min
+#define min(a, b) ((a)<=(b) ? (a) : (b))
 #endif
 
 /*-------------------------------------------------------------*/
 void swap(PList *a, int i, int j) {
 	PList t = a[i];
 	a[i] = a[j];
-	a[j] = t; 
+	a[j] = t;
 }
 /*--------------------------------------------------------------*/
 void vecswap(PList *a, int i, int j, int n) {
@@ -84,7 +86,7 @@ void ssort(PList *a, int n, int depth) {
 	swap(a, 0, pm);
 	v = a[0]->msgnr[depth];
 	for (le = 1; le < n && a[le]->msgnr[depth] == v; le++) {
-		;	
+		;
 	}
 	if (le == n) {
 		if (v != 0) {
@@ -118,33 +120,33 @@ void ssort(PList *a, int n, int depth) {
 	if (v != 0) {
 		ssort(a + lt-le, le + n-ge-1, depth+1);
 	}
-	ssort(a + n-(ge-gt), ge-gt, depth); 
-} 
+	ssort(a + n-(ge-gt), ge-gt, depth);
+}
 /*-------------------------------------------------------------------------------*/
 PList my_bsearch(PList *arr, char *matchnr, int nrin) {
 
-	int val, index, left = 0, right = nrin ;
-	
+	int val, my_index, left = 0, right = nrin ;
+
 	PList retval = NULL;
-	
+
 	while( left < right ) {
-		index = ( right + left) / 2;  /* find halfway pt */
-		
-		val = qcmp_msgid(matchnr, arr[index]->msgnr);
-		
+		my_index = ( right + left) / 2;  /* find halfway pt */
+
+		val = qcmp_msgid(matchnr, arr[my_index]->msgnr);
+
 		if(val < 0) {
-			right = index ;
+			right = my_index ;
 		}
 		else if(val > 0) {
-			left = index + 1;
+			left = my_index + 1;
 		}
 		else {
-			retval = arr[index];
+			retval = arr[my_index];
 			break;
 		}
-		
+
 	}
 
 	return retval;
 }
- 
+
